@@ -16,6 +16,10 @@ def get_items():
         print("path test: true")
 
         with open(path, "r") as file:
-            ITEMLIST = [item.strip() for item in file.readlines()]
+            items = [item.strip() for item in file.readlines()]
+            print(f"items = {items}")
+            ITEMLIST = items
+
+        print(f"ITEMLIST = {ITEMLIST}")
     else:
         print("failed")
\ No newline at end of file
